@@ -8,7 +8,6 @@ import requests
 
 from ..base import GenericAPI, ERROR_THRESHOLD
 from ...metadata import MetadataItem
-from ... import utils
 
 from ._construction import algorithms as alg, xml_generation as xmlgen
 
@@ -498,9 +497,6 @@ class WorkflowAPI(GenericAPI):
                 'column': sort_field,
                 'sortDirection': sort_direction,
             },
-            headers=self._auth.get_headers(),
-            cookies=self._auth.get_cookies(),
-            verify=self.auth.verify,
         )
         r = self.attempt_api_call(curried_request=curried_request)
 
@@ -540,9 +536,6 @@ class WorkflowAPI(GenericAPI):
                 'column': sort_field,
                 'sortDirection': sort_direction,
             },
-            headers=self._auth.get_headers(),
-            cookies=self._auth.get_cookies(),
-            verify=self.auth.verify,
         )
         r = self.attempt_api_call(curried_request=curried_request)
 
@@ -582,9 +575,6 @@ class WorkflowAPI(GenericAPI):
         curried_request = partial(
             requests.get,
             url=url,
-            cookies=self._auth.get_cookies(),
-            headers=self._auth.get_headers(),
-            verify=self.auth.verify,
         )
         r = self.attempt_api_call(curried_request=curried_request)
 
@@ -612,9 +602,6 @@ class WorkflowAPI(GenericAPI):
         curried_request = partial(
             requests.get,
             url=f"{self._workflow_base_url}process/{document_id}/",
-            headers=self._auth.get_headers(),
-            cookies=self._auth.get_cookies(),
-            verify=self.auth.verify,
         )
         r = self.attempt_api_call(curried_request=curried_request)
 
@@ -634,14 +621,23 @@ class WorkflowAPI(GenericAPI):
 
         document_id = updated_document.pop('id')
 
+        # Transform data to fit endpoint spec.
+        if 'content' in updated_document:
+            updates = updated_document['content']
+
+            if 'metadata' in updated_document and updated_document['metadata']:
+                updates['metadata'] = updated_document['metadata']
+        else:
+            updates = updated_document
+
+        if 'comments' in updates:
+            updates.pop('comments')
+
         url = f"{self._base_url}/api/workflow/process/{document_id}/"
         curried_request = partial(
             requests.patch,
             url=url,
-            json=updated_document,
-            headers=self._auth.get_headers(),
-            cookies=self._auth.get_cookies(),
-            verify=self.auth.verify,
+            json=updates,
         )
         # TODO:  Surround all such calls by try/except.  Report errors.
         r = self.attempt_api_call(curried_request)
@@ -738,9 +734,6 @@ class WorkflowAPI(GenericAPI):
             requests.post,
             url=url,
             json=payload,
-            headers=self._auth.get_headers(),
-            cookies=self._auth.get_cookies(),
-            verify=self.auth.verify,
         )
         r = self.attempt_api_call(curried_request)
 
@@ -825,9 +818,6 @@ class WorkflowAPI(GenericAPI):
             requests.post,
             url=url,
             json=payload,
-            headers=self._auth.get_headers(),
-            cookies=self._auth.get_cookies(),
-            verify=self.auth.verify,
         )
         r = self.attempt_api_call(curried_request)
 
