@@ -16,9 +16,12 @@ import requests
 import urllib3
 
 
-# Number of seconds prior to expiration when a refresh request should be
-# initiated.
-REFRESH_MARGIN = 200
+# Attempt to refresh token if time to live is fewer than this many seconds.
+REFRESH_WINDOW = 300
+
+# Sleep time between refresh attempts.
+REFRESH_RETRY_SLEEP_TIME = 1
+
 
 # Disable insecure request warnings.
 urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
@@ -38,6 +41,13 @@ class Authorization:
         Base-64 encoded text containing a dict with authorization info.
     verify : bool
         SSL verification, set to True by default.
+    delayed_refresh : bool
+        This parameter is mainly useful for unit tests.  Accept the default
+        (False) otherwise.
+        The default behavior is to refresh the auth token immediately, so that
+        refresh failures can be detected and users will not have such a failure
+        an hour into a long-running script.  Unit tests rely on an auth string,
+        which will not be valid for subsequent tests if the token is refreshed.
 
     Public methods
     --------------
@@ -74,7 +84,9 @@ class Authorization:
         'refreshToken',     # Token to refresh access / get a new access token.
     )
 
-    def __init__(self, auth_payload, verify=True):
+    def __init__(self, auth_payload, verify=True, delayed_refresh=False):
+        self._verify = bool(verify)
+        self._delayed_refresh = bool(delayed_refresh)
         auth_payload = json.loads(base64.b64decode(auth_payload))
 
         # TODO:  Improve upon parameter validation.
@@ -104,30 +116,13 @@ class Authorization:
         expiration_time = dateutil.parser.parse(auth_payload['expiresAt'])
         current_time = datetime.now(tzlocal())
         time_delta = expiration_time - current_time
-        seconds_to_expiration = time_delta.total_seconds()
-        self._refresh_margin = REFRESH_MARGIN
-
-        if seconds_to_expiration < self._refresh_margin:
-            raise AuthExpirationException(
-                (
-                    'Insufficient margin for access token refresh.\n'
-                    'Margin: {}\n'
-                    'Expires in: {}\n'
-                ).format(
-                    self._refresh_margin,
-                    seconds_to_expiration
-                )
-            )
-
-        self._refresh_sleep_time = seconds_to_expiration - self._refresh_margin
+        self._seconds_to_expiration = time_delta.total_seconds()
 
         # Define a refresh thread without starting it.
         self._refresh_thread = Thread(target=self._refresh)
         self._refresh_thread.setDaemon(True)
         self._refresh_thread.start()
 
-        self._verify = verify
-
     @property
     def verify(self):
         return self._verify
@@ -213,8 +208,21 @@ class Authorization:
         It should run as long as the client application is running, to ensure
         that the user is continuously authorized.
         """
-        while True:
-            sleep(self._refresh_sleep_time)
+        if self._seconds_to_expiration < 0:
+            raise AuthExpirationException(
+                "Unable to authenticate with expired token")
+
+        # Request object, defined here for post-loop error handling.
+        r = None
+
+        while self._seconds_to_expiration >= 0:
+            if self._delayed_refresh:
+                sleep_time = max(
+                    self._seconds_to_expiration - REFRESH_WINDOW, 0)
+                sleep(sleep_time)
+                # Delayed refresh is only relevant for the first loop
+                # iteration.
+                self._delayed_refresh = False
 
             data = {
                 'client_id': self._client_id,
@@ -231,24 +239,21 @@ class Authorization:
             )
 
             if r.status_code >= 400:
-                raise Exception("Attempt to set tokens by calling "
-                                f"{self._token_url} has failed")
+                sleep(REFRESH_RETRY_SLEEP_TIME)
+                continue
 
             auth_info = r.json()
             self._access_token = auth_info['access_token']
             self._refresh_token = auth_info['refresh_token']
-            seconds_to_expiration = auth_info['expires_in']
+            self._seconds_to_expiration = auth_info['expires_in']
 
-            if seconds_to_expiration < self._refresh_margin:
-                raise Exception(
-                    (
-                        'Insufficient margin for access token refresh.\n'
-                        'Margin: {}\n'
-                        'Expires in: {}\n'
-                    ).format(
-                        self._refresh_margin,
-                        seconds_to_expiration
-                    )
-                )
+            sleep_time = max(self._seconds_to_expiration - REFRESH_WINDOW, 0)
+            sleep(sleep_time)
 
-            self._refresh_sleep_time = seconds_to_expiration - self._refresh_margin
+        if r is not None:
+            raise AuthExpirationException(
+                "Unable to refresh token. "
+                f"Call to {self._token_url} has failed. "
+                f"Status code: {r.status_code}. "
+                f"Response: {r.content.decode()}."
+            )
