@@ -14,7 +14,7 @@ class InvalidMetadataFormatException(Exception):
 
 
 def get_active_path(path):
-    """Get a path that can be used to get a file size, read/write a file, etc."""
+    """Get a path that can be used to get size, read/write, etc."""
     path = path.replace('\\', '/')
 
     if platform.system() != 'Windows' or path.startswith(WINDOWS_PATH_PREFIX):
